LottieGenImage class

Constructors

LottieGenImage(String _assetName)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
keyName String
no setter
path String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

custom({Key? key, required Widget builder(BuildContext context, String assetPath)}) Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited